==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebToggleDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewEventArgsDescriptionMetadata } from "./WebToggleViewEventArgsDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDescriptionMetadata } from "./WebToggleViewCancelableEventArgsDescriptionMetadata";
import { WebToggleDirectiveDescription } from "./WebToggleDirectiveDescription";
/**
 * @hidden
 */
var WebToggleDirectiveDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebToggleDirectiveDescriptionMetadata, _super);
    function WebToggleDirectiveDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleDirectiveDescriptionMetadata.b = function (a) {
        if (WebToggleDirectiveDescriptionMetadata.a == null) {
            WebToggleDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleDirectiveDescriptionMetadata.c(WebToggleDirectiveDescriptionMetadata.a);
        }
        if (a.j(WebToggleDirectiveDescriptionMetadata.a)) {
            return;
        }
        a.y(WebToggleDirectiveDescriptionMetadata.a);
        WebToggleViewEventArgsDescriptionMetadata.d(a);
        WebToggleViewCancelableEventArgsDescriptionMetadata.d(a);
    };
    WebToggleDirectiveDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ToggleDirective");
        a.item("__packageNameWC", "String:grids");
        a.item("Id", "String");
        a.item("OpenedRef", "EventRef::opened:customEvent");
        a.item("OpeningRef", "EventRef::opening:customEvent");
        a.item("ClosedRef", "EventRef::closed:customEvent");
        a.item("ClosingRef", "EventRef::closing:customEvent");
        a.item("AppendedRef", "EventRef::appended:customEvent");
    };
    WebToggleDirectiveDescriptionMetadata.d = function (a) {
        WebToggleDirectiveDescriptionMetadata.b(a);
        a.aa("WebToggleDirective", function () { return new WebToggleDirectiveDescription(); });
        a.z("WebToggleDirective", WebToggleDirectiveDescriptionMetadata.a);
    };
    WebToggleDirectiveDescriptionMetadata.$t = markType(WebToggleDirectiveDescriptionMetadata, 'WebToggleDirectiveDescriptionMetadata');
    WebToggleDirectiveDescriptionMetadata.a = null;
    return WebToggleDirectiveDescriptionMetadata;
}(Base));
export { WebToggleDirectiveDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebToggleDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewEventArgsDescriptionMetadata } from "./WebToggleViewEventArgsDescriptionMetadata";
import { WebToggleViewCancelableEventArgsDescriptionMetadata } from "./WebToggleViewCancelableEventArgsDescriptionMetadata";
import { WebToggleDirectiveDescription } from "./WebToggleDirectiveDescription";
/**
 * @hidden
 */
var WebToggleDirectiveDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebToggleDirectiveDescriptionMetadata, _super);
    function WebToggleDirectiveDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebToggleDirectiveDescriptionMetadata.b = function (a) {
        if (WebToggleDirectiveDescriptionMetadata.a == null) {
            WebToggleDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebToggleDirectiveDescriptionMetadata.c(WebToggleDirectiveDescriptionMetadata.a);
        }
        if (a.k(WebToggleDirectiveDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebToggleDirectiveDescriptionMetadata.a);
        WebToggleViewEventArgsDescriptionMetadata.d(a);
        WebToggleViewCancelableEventArgsDescriptionMetadata.d(a);
    };
    WebToggleDirectiveDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ToggleDirective");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__skipSuffix", "Boolean");
        a.item("Id", "String");
        a.item("OpenedRef", "EventRef::opened:customEvent");
        a.item("OpeningRef", "EventRef::opening:customEvent");
        a.item("ClosedRef", "EventRef::closed:customEvent");
        a.item("ClosingRef", "EventRef::closing:customEvent");
        a.item("AppendedRef", "EventRef::appended:customEvent");
    };
    WebToggleDirectiveDescriptionMetadata.d = function (a) {
        WebToggleDirectiveDescriptionMetadata.b(a);
        a.ac("WebToggleDirective", function () { return new WebToggleDirectiveDescription(); });
        a.ab("WebToggleDirective", WebToggleDirectiveDescriptionMetadata.a);
    };
    WebToggleDirectiveDescriptionMetadata.$t = markType(WebToggleDirectiveDescriptionMetadata, 'WebToggleDirectiveDescriptionMetadata');
    WebToggleDirectiveDescriptionMetadata.a = null;
    return WebToggleDirectiveDescriptionMetadata;
}(Base));
export { WebToggleDirectiveDescriptionMetadata };
